Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(306)

Unified Diff: chrome/browser/image_decoder.h

Issue 9317074: Create an API around UtilityProcessHost and use that from chrome. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/first_run/first_run_win.cc ('k') | chrome/browser/image_decoder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/image_decoder.h
===================================================================
--- chrome/browser/image_decoder.h (revision 120256)
+++ chrome/browser/image_decoder.h (working copy)
@@ -10,12 +10,13 @@
#include <vector>
#include "base/compiler_specific.h"
-#include "content/browser/utility_process_host.h"
+#include "content/public/browser/browser_thread.h"
+#include "content/public/browser/utility_process_host_client.h"
class SkBitmap;
// Decodes an image in a sandboxed process.
-class ImageDecoder : public UtilityProcessHost::Client {
+class ImageDecoder : public content::UtilityProcessHostClient {
public:
class Delegate {
public:
@@ -43,7 +44,7 @@
// It's a reference counted object, so destructor is private.
virtual ~ImageDecoder();
// Overidden from UtilityProcessHost::Client:
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// IPC message handlers.
« no previous file with comments | « chrome/browser/first_run/first_run_win.cc ('k') | chrome/browser/image_decoder.cc » ('j') | no next file with comments »
@@ -43,7 +44,7 @@
// It's a reference counted object, so destructor is private.
virtual ~ImageDecoder();
- // Overidden from UtilityProcessHost::Client:
+ // Overidden from UtilityProcessHostClient:
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// IPC message handlers.

Powered by Google App Engine
This is Rietveld 408576698